/*
 * This is part of Geomajas, a GIS framework, http://www.geomajas.org/.
 *
 * Copyright 2008-2011 Geosparc nv, http://www.geosparc.com/, Belgium.
 *
 * The program is available in open source according to the GNU Affero
 * General Public License. All contributions in this program are covered
 * by the Geomajas Contributors License Agreement. For full licensing
 * details, see LICENSE.txt in the project root.
 */

package org.geomajas.gwt.client.map.event;

import org.geomajas.global.Api;
import org.geomajas.gwt.client.map.MapView.ZoomOption;
import org.geomajas.gwt.client.spatial.Bbox;

import com.google.gwt.event.shared.GwtEvent;

/**
 * Custom defined event that is triggered every time the view on a map changes. This can be due to zooming in or
 * panning. This event contains the new bounding box and scale.
 * 
 * @author Pieter De Graef
 * @since 1.6.0
 */
@Api(allMethods = true)
public class MapViewChangedEvent extends GwtEvent<MapViewChangedHandler> {

	/**
	 * Handler type.
	 */
	private static Type<MapViewChangedHandler> TYPE;

	/**
	 * The new bounding box that has been applied on the map.
	 */
	private Bbox bounds;

	/**
	 * The map's current scale.
	 */
	private double scale;

	/**
	 * Is it a panning event ?
	 */
	private boolean sameScaleLevel;

	private boolean panDragging;

	private boolean mapResized;

	private ZoomOption zoomOption;
	/**
	 * 
	 * @param bounds
	 * @param scale
	 * @param panning
	 */

	// -------------------------------------------------------------------------
	// Constructor:
	// -------------------------------------------------------------------------
	public MapViewChangedEvent(Bbox bounds, double scale, boolean sameScaleLevel, boolean panDragging,
			boolean mapResized, ZoomOption zoomOption) {
		this.bounds = bounds;
		this.scale = scale;
		this.sameScaleLevel = sameScaleLevel;
		this.panDragging = panDragging;
		this.mapResized = mapResized;
		this.zoomOption = zoomOption;
	}

	// -------------------------------------------------------------------------
	// Event implementation:
	// -------------------------------------------------------------------------

	/**
	 * Get the type associated with this event.
	 * 
	 * @return returns the handler type
	 */
	public static Type<MapViewChangedHandler> getType() {
		if (TYPE == null) {
			TYPE = new Type<MapViewChangedHandler>();
		}
		return TYPE;
	}

	protected void dispatch(MapViewChangedHandler handler) {
		handler.onMapViewChanged(this);
	}

	public final Type<MapViewChangedHandler> getAssociatedType() {
		return TYPE;
	}

	// -------------------------------------------------------------------------
	// Getters:
	// -------------------------------------------------------------------------

	public Bbox getBounds() {
		return bounds;
	}

	public double getScale() {
		return scale;
	}

	public boolean isSameScaleLevel() {
		return sameScaleLevel;
	}

	public boolean isPanDragging() {
		return panDragging;
	}

	public boolean isMapResized() {
		return mapResized;
	}
	
	public ZoomOption getZoomOption() {
		return zoomOption;
	}
	
}
